// Copyright 2012 The Go Authors.  All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// +build darwin freebsd linux netbsd openbsd windows

package net

import (
	"syscall"
	"testing"
)

var tcpSelfConnectTests = []struct {
	fd  *netFD
	err error
	ok  bool
}{
	{&netFD{laddr: nullProtocolAddr(syscall.AF_INET, syscall.SOCK_STREAM), raddr: nullProtocolAddr(syscall.AF_INET, syscall.SOCK_STREAM)}, nil, true},
	{&netFD{laddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1024}, raddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1024}}, nil, true},
	{&netFD{laddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1024}, raddr: &TCPAddr{IP: IPv4(127, 0, 0, 2), Port: 1023}}, nil, false},
	{&netFD{laddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1024}, raddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1023}}, nil, false},
	{&netFD{laddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1024}, raddr: &TCPAddr{IP: IPv4(127, 0, 0, 1), Port: 1024}}, errClosing, false},
}

func TestTCPSelfConnect(t *testing.T) {
	for _, tt := range tcpSelfConnectTests {
		if ok := selfConnect(tt.fd, tt.err); ok != tt.ok {
			t.Fatalf("selfConnect = %v; want %v", ok, tt.ok)
		}
	}
}
